@@ -52,8 +52,8 @@ def main():
 		head = data[0,:]
 		data = data[1:,:]
 		data = data.astype('float64')
-		x = data[:,1:]
-		y = data[:,1]
+		x = data[:,:-1]
+		y = data[:,-1]
 		row = len(x)
 		col = len(x[0])
 		w = [float(w) for w in sys.argv[3].split(',')]
